@@ -61,6 +61,11 @@ impl AsyncApi {
     async_caller(&self.api, add_chat_members.as_ref()).await
   }
 
+  pub async fn add_contact<C: AsRef<AddContact>>(&self, add_contact: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, add_contact.as_ref()).await
+  }
+
   pub async fn add_custom_server_language_pack<C: AsRef<AddCustomServerLanguagePack>>(&self, add_custom_server_language_pack: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, add_custom_server_language_pack.as_ref()).await
@@ -141,6 +146,11 @@ impl AsyncApi {
     async_caller(&self.api, block_user.as_ref()).await
   }
 
+  pub async fn can_transfer_ownership<C: AsRef<CanTransferOwnership>>(&self, can_transfer_ownership: C) -> RTDResult<CanTransferOwnershipResult> {
+    async_caller!(CanTransferOwnershipResult);
+    async_caller(&self.api, can_transfer_ownership.as_ref()).await
+  }
+
   pub async fn cancel_download_file<C: AsRef<CancelDownloadFile>>(&self, cancel_download_file: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, cancel_download_file.as_ref()).await
@@ -151,11 +161,6 @@ impl AsyncApi {
     async_caller(&self.api, cancel_upload_file.as_ref()).await
   }
 
-  pub async fn change_chat_report_spam_state<C: AsRef<ChangeChatReportSpamState>>(&self, change_chat_report_spam_state: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
-    async_caller(&self.api, change_chat_report_spam_state.as_ref()).await
-  }
-
   pub async fn change_imported_contacts<C: AsRef<ChangeImportedContacts>>(&self, change_imported_contacts: C) -> RTDResult<ImportedContacts> {
     async_caller!(ImportedContacts);
     async_caller(&self.api, change_imported_contacts.as_ref()).await
@@ -201,6 +206,11 @@ impl AsyncApi {
     async_caller(&self.api, check_chat_username.as_ref()).await
   }
 
+  pub async fn check_created_public_chats_limit<C: AsRef<CheckCreatedPublicChatsLimit>>(&self, check_created_public_chats_limit: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, check_created_public_chats_limit.as_ref()).await
+  }
+
   pub async fn check_database_encryption_key<C: AsRef<CheckDatabaseEncryptionKey>>(&self, check_database_encryption_key: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, check_database_encryption_key.as_ref()).await
@@ -266,6 +276,11 @@ impl AsyncApi {
     async_caller(&self.api, close_secret_chat.as_ref()).await
   }
 
+  pub async fn confirm_qr_code_authentication<C: AsRef<ConfirmQrCodeAuthentication>>(&self, confirm_qr_code_authentication: C) -> RTDResult<Session> {
+    async_caller!(Session);
+    async_caller(&self.api, confirm_qr_code_authentication.as_ref()).await
+  }
+
   pub async fn create_basic_group_chat<C: AsRef<CreateBasicGroupChat>>(&self, create_basic_group_chat: C) -> RTDResult<Chat> {
     async_caller!(Chat);
     async_caller(&self.api, create_basic_group_chat.as_ref()).await
@@ -456,6 +471,11 @@ impl AsyncApi {
     async_caller(&self.api, edit_message_reply_markup.as_ref()).await
   }
 
+  pub async fn edit_message_scheduling_state<C: AsRef<EditMessageSchedulingState>>(&self, edit_message_scheduling_state: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, edit_message_scheduling_state.as_ref()).await
+  }
+
   pub async fn edit_message_text<C: AsRef<EditMessageText>>(&self, edit_message_text: C) -> RTDResult<Message> {
     async_caller!(Message);
     async_caller(&self.api, edit_message_text.as_ref()).await
@@ -526,6 +546,21 @@ impl AsyncApi {
     async_caller(&self.api, get_authorization_state.as_ref()).await
   }
 
+  pub async fn get_auto_download_settings_presets<C: AsRef<GetAutoDownloadSettingsPresets>>(&self, get_auto_download_settings_presets: C) -> RTDResult<AutoDownloadSettingsPresets> {
+    async_caller!(AutoDownloadSettingsPresets);
+    async_caller(&self.api, get_auto_download_settings_presets.as_ref()).await
+  }
+
+  pub async fn get_background_url<C: AsRef<GetBackgroundUrl>>(&self, get_background_url: C) -> RTDResult<HttpUrl> {
+    async_caller!(HttpUrl);
+    async_caller(&self.api, get_background_url.as_ref()).await
+  }
+
+  pub async fn get_backgrounds<C: AsRef<GetBackgrounds>>(&self, get_backgrounds: C) -> RTDResult<Backgrounds> {
+    async_caller!(Backgrounds);
+    async_caller(&self.api, get_backgrounds.as_ref()).await
+  }
+
   pub async fn get_basic_group<C: AsRef<GetBasicGroup>>(&self, get_basic_group: C) -> RTDResult<BasicGroup> {
     async_caller!(BasicGroup);
     async_caller(&self.api, get_basic_group.as_ref()).await
@@ -551,8 +586,8 @@ impl AsyncApi {
     async_caller(&self.api, get_chat.as_ref()).await
   }
 
-  pub async fn get_chat_administrators<C: AsRef<GetChatAdministrators>>(&self, get_chat_administrators: C) -> RTDResult<Users> {
-    async_caller!(Users);
+  pub async fn get_chat_administrators<C: AsRef<GetChatAdministrators>>(&self, get_chat_administrators: C) -> RTDResult<ChatAdministrators> {
+    async_caller!(ChatAdministrators);
     async_caller(&self.api, get_chat_administrators.as_ref()).await
   }
 
@@ -591,9 +626,9 @@ impl AsyncApi {
     async_caller(&self.api, get_chat_pinned_message.as_ref()).await
   }
 
-  pub async fn get_chat_report_spam_state<C: AsRef<GetChatReportSpamState>>(&self, get_chat_report_spam_state: C) -> RTDResult<ChatReportSpamState> {
-    async_caller!(ChatReportSpamState);
-    async_caller(&self.api, get_chat_report_spam_state.as_ref()).await
+  pub async fn get_chat_scheduled_messages<C: AsRef<GetChatScheduledMessages>>(&self, get_chat_scheduled_messages: C) -> RTDResult<Messages> {
+    async_caller!(Messages);
+    async_caller(&self.api, get_chat_scheduled_messages.as_ref()).await
   }
 
   pub async fn get_chat_statistics_url<C: AsRef<GetChatStatisticsUrl>>(&self, get_chat_statistics_url: C) -> RTDResult<HttpUrl> {
@@ -641,6 +676,11 @@ impl AsyncApi {
     async_caller(&self.api, get_deep_link_info.as_ref()).await
   }
 
+  pub async fn get_emoji_suggestions_url<C: AsRef<GetEmojiSuggestionsUrl>>(&self, get_emoji_suggestions_url: C) -> RTDResult<HttpUrl> {
+    async_caller!(HttpUrl);
+    async_caller(&self.api, get_emoji_suggestions_url.as_ref()).await
+  }
+
   pub async fn get_favorite_stickers<C: AsRef<GetFavoriteStickers>>(&self, get_favorite_stickers: C) -> RTDResult<Stickers> {
     async_caller!(Stickers);
     async_caller(&self.api, get_favorite_stickers.as_ref()).await
@@ -681,6 +721,11 @@ impl AsyncApi {
     async_caller(&self.api, get_imported_contact_count.as_ref()).await
   }
 
+  pub async fn get_inactive_supergroup_chats<C: AsRef<GetInactiveSupergroupChats>>(&self, get_inactive_supergroup_chats: C) -> RTDResult<Chats> {
+    async_caller!(Chats);
+    async_caller(&self.api, get_inactive_supergroup_chats.as_ref()).await
+  }
+
   pub async fn get_inline_game_high_scores<C: AsRef<GetInlineGameHighScores>>(&self, get_inline_game_high_scores: C) -> RTDResult<GameHighScores> {
     async_caller!(GameHighScores);
     async_caller(&self.api, get_inline_game_high_scores.as_ref()).await
@@ -751,6 +796,16 @@ impl AsyncApi {
     async_caller(&self.api, get_log_verbosity_level.as_ref()).await
   }
 
+  pub async fn get_login_url<C: AsRef<GetLoginUrl>>(&self, get_login_url: C) -> RTDResult<HttpUrl> {
+    async_caller!(HttpUrl);
+    async_caller(&self.api, get_login_url.as_ref()).await
+  }
+
+  pub async fn get_login_url_info<C: AsRef<GetLoginUrlInfo>>(&self, get_login_url_info: C) -> RTDResult<LoginUrlInfo> {
+    async_caller!(LoginUrlInfo);
+    async_caller(&self.api, get_login_url_info.as_ref()).await
+  }
+
   pub async fn get_map_thumbnail_file<C: AsRef<GetMapThumbnailFile>>(&self, get_map_thumbnail_file: C) -> RTDResult<File> {
     async_caller!(File);
     async_caller(&self.api, get_map_thumbnail_file.as_ref()).await
@@ -771,6 +826,11 @@ impl AsyncApi {
     async_caller(&self.api, get_message_link.as_ref()).await
   }
 
+  pub async fn get_message_link_info<C: AsRef<GetMessageLinkInfo>>(&self, get_message_link_info: C) -> RTDResult<MessageLinkInfo> {
+    async_caller!(MessageLinkInfo);
+    async_caller(&self.api, get_message_link_info.as_ref()).await
+  }
+
   pub async fn get_message_locally<C: AsRef<GetMessageLocally>>(&self, get_message_locally: C) -> RTDResult<Message> {
     async_caller!(Message);
     async_caller(&self.api, get_message_locally.as_ref()).await
@@ -821,6 +881,11 @@ impl AsyncApi {
     async_caller(&self.api, get_payment_receipt.as_ref()).await
   }
 
+  pub async fn get_poll_voters<C: AsRef<GetPollVoters>>(&self, get_poll_voters: C) -> RTDResult<Users> {
+    async_caller!(Users);
+    async_caller(&self.api, get_poll_voters.as_ref()).await
+  }
+
   pub async fn get_preferred_country_language<C: AsRef<GetPreferredCountryLanguage>>(&self, get_preferred_country_language: C) -> RTDResult<Text> {
     async_caller!(Text);
     async_caller(&self.api, get_preferred_country_language.as_ref()).await
@@ -896,8 +961,8 @@ impl AsyncApi {
     async_caller(&self.api, get_secret_chat.as_ref()).await
   }
 
-  pub async fn get_sticker_emojis<C: AsRef<GetStickerEmojis>>(&self, get_sticker_emojis: C) -> RTDResult<StickerEmojis> {
-    async_caller!(StickerEmojis);
+  pub async fn get_sticker_emojis<C: AsRef<GetStickerEmojis>>(&self, get_sticker_emojis: C) -> RTDResult<Emojis> {
+    async_caller!(Emojis);
     async_caller(&self.api, get_sticker_emojis.as_ref()).await
   }
 
@@ -921,6 +986,11 @@ impl AsyncApi {
     async_caller(&self.api, get_storage_statistics_fast.as_ref()).await
   }
 
+  pub async fn get_suitable_discussion_chats<C: AsRef<GetSuitableDiscussionChats>>(&self, get_suitable_discussion_chats: C) -> RTDResult<Chats> {
+    async_caller!(Chats);
+    async_caller(&self.api, get_suitable_discussion_chats.as_ref()).await
+  }
+
   pub async fn get_supergroup<C: AsRef<GetSupergroup>>(&self, get_supergroup: C) -> RTDResult<Supergroup> {
     async_caller!(Supergroup);
     async_caller(&self.api, get_supergroup.as_ref()).await
@@ -981,11 +1051,6 @@ impl AsyncApi {
     async_caller(&self.api, get_user_profile_photos.as_ref()).await
   }
 
-  pub async fn get_wallpapers<C: AsRef<GetWallpapers>>(&self, get_wallpapers: C) -> RTDResult<Wallpapers> {
-    async_caller!(Wallpapers);
-    async_caller(&self.api, get_wallpapers.as_ref()).await
-  }
-
   pub async fn get_web_page_instant_view<C: AsRef<GetWebPageInstantView>>(&self, get_web_page_instant_view: C) -> RTDResult<WebPageInstantView> {
     async_caller!(WebPageInstantView);
     async_caller(&self.api, get_web_page_instant_view.as_ref()).await
@@ -1081,6 +1146,21 @@ impl AsyncApi {
     async_caller(&self.api, register_device.as_ref()).await
   }
 
+  pub async fn register_user<C: AsRef<RegisterUser>>(&self, register_user: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, register_user.as_ref()).await
+  }
+
+  pub async fn remove_background<C: AsRef<RemoveBackground>>(&self, remove_background: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, remove_background.as_ref()).await
+  }
+
+  pub async fn remove_chat_action_bar<C: AsRef<RemoveChatActionBar>>(&self, remove_chat_action_bar: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, remove_chat_action_bar.as_ref()).await
+  }
+
   pub async fn remove_contacts<C: AsRef<RemoveContacts>>(&self, remove_contacts: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, remove_contacts.as_ref()).await
@@ -1161,6 +1241,11 @@ impl AsyncApi {
     async_caller(&self.api, request_password_recovery.as_ref()).await
   }
 
+  pub async fn request_qr_code_authentication<C: AsRef<RequestQrCodeAuthentication>>(&self, request_qr_code_authentication: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, request_qr_code_authentication.as_ref()).await
+  }
+
   pub async fn resend_authentication_code<C: AsRef<ResendAuthenticationCode>>(&self, resend_authentication_code: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, resend_authentication_code.as_ref()).await
@@ -1176,6 +1261,11 @@ impl AsyncApi {
     async_caller(&self.api, resend_email_address_verification_code.as_ref()).await
   }
 
+  pub async fn resend_messages<C: AsRef<ResendMessages>>(&self, resend_messages: C) -> RTDResult<Messages> {
+    async_caller!(Messages);
+    async_caller(&self.api, resend_messages.as_ref()).await
+  }
+
   pub async fn resend_phone_number_confirmation_code<C: AsRef<ResendPhoneNumberConfirmationCode>>(&self, resend_phone_number_confirmation_code: C) -> RTDResult<AuthenticationCodeInfo> {
     async_caller!(AuthenticationCodeInfo);
     async_caller(&self.api, resend_phone_number_confirmation_code.as_ref()).await
@@ -1196,6 +1286,11 @@ impl AsyncApi {
     async_caller(&self.api, reset_all_notification_settings.as_ref()).await
   }
 
+  pub async fn reset_backgrounds<C: AsRef<ResetBackgrounds>>(&self, reset_backgrounds: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, reset_backgrounds.as_ref()).await
+  }
+
   pub async fn reset_network_statistics<C: AsRef<ResetNetworkStatistics>>(&self, reset_network_statistics: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, reset_network_statistics.as_ref()).await
@@ -1206,6 +1301,11 @@ impl AsyncApi {
     async_caller(&self.api, save_application_log_event.as_ref()).await
   }
 
+  pub async fn search_background<C: AsRef<SearchBackground>>(&self, search_background: C) -> RTDResult<Background> {
+    async_caller!(Background);
+    async_caller(&self.api, search_background.as_ref()).await
+  }
+
   pub async fn search_call_messages<C: AsRef<SearchCallMessages>>(&self, search_call_messages: C) -> RTDResult<Messages> {
     async_caller!(Messages);
     async_caller(&self.api, search_call_messages.as_ref()).await
@@ -1231,6 +1331,11 @@ impl AsyncApi {
     async_caller(&self.api, search_chats.as_ref()).await
   }
 
+  pub async fn search_chats_nearby<C: AsRef<SearchChatsNearby>>(&self, search_chats_nearby: C) -> RTDResult<ChatsNearby> {
+    async_caller!(ChatsNearby);
+    async_caller(&self.api, search_chats_nearby.as_ref()).await
+  }
+
   pub async fn search_chats_on_server<C: AsRef<SearchChatsOnServer>>(&self, search_chats_on_server: C) -> RTDResult<Chats> {
     async_caller!(Chats);
     async_caller(&self.api, search_chats_on_server.as_ref()).await
@@ -1241,6 +1346,11 @@ impl AsyncApi {
     async_caller(&self.api, search_contacts.as_ref()).await
   }
 
+  pub async fn search_emojis<C: AsRef<SearchEmojis>>(&self, search_emojis: C) -> RTDResult<Emojis> {
+    async_caller!(Emojis);
+    async_caller(&self.api, search_emojis.as_ref()).await
+  }
+
   pub async fn search_hashtags<C: AsRef<SearchHashtags>>(&self, search_hashtags: C) -> RTDResult<Hashtags> {
     async_caller!(Hashtags);
     async_caller(&self.api, search_hashtags.as_ref()).await
@@ -1376,6 +1486,16 @@ impl AsyncApi {
     async_caller(&self.api, set_authentication_phone_number.as_ref()).await
   }
 
+  pub async fn set_auto_download_settings<C: AsRef<SetAutoDownloadSettings>>(&self, set_auto_download_settings: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_auto_download_settings.as_ref()).await
+  }
+
+  pub async fn set_background<C: AsRef<SetBackground>>(&self, set_background: C) -> RTDResult<Background> {
+    async_caller!(Background);
+    async_caller(&self.api, set_background.as_ref()).await
+  }
+
   pub async fn set_bio<C: AsRef<SetBio>>(&self, set_bio: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_bio.as_ref()).await
@@ -1386,16 +1506,36 @@ impl AsyncApi {
     async_caller(&self.api, set_bot_updates_status.as_ref()).await
   }
 
+  pub async fn set_chat_chat_list<C: AsRef<SetChatChatList>>(&self, set_chat_chat_list: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_chat_list.as_ref()).await
+  }
+
   pub async fn set_chat_client_data<C: AsRef<SetChatClientData>>(&self, set_chat_client_data: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_client_data.as_ref()).await
   }
 
+  pub async fn set_chat_description<C: AsRef<SetChatDescription>>(&self, set_chat_description: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_description.as_ref()).await
+  }
+
+  pub async fn set_chat_discussion_group<C: AsRef<SetChatDiscussionGroup>>(&self, set_chat_discussion_group: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_discussion_group.as_ref()).await
+  }
+
   pub async fn set_chat_draft_message<C: AsRef<SetChatDraftMessage>>(&self, set_chat_draft_message: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_draft_message.as_ref()).await
   }
 
+  pub async fn set_chat_location<C: AsRef<SetChatLocation>>(&self, set_chat_location: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_location.as_ref()).await
+  }
+
   pub async fn set_chat_member_status<C: AsRef<SetChatMemberStatus>>(&self, set_chat_member_status: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_member_status.as_ref()).await
@@ -1406,11 +1546,21 @@ impl AsyncApi {
     async_caller(&self.api, set_chat_notification_settings.as_ref()).await
   }
 
+  pub async fn set_chat_permissions<C: AsRef<SetChatPermissions>>(&self, set_chat_permissions: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_permissions.as_ref()).await
+  }
+
   pub async fn set_chat_photo<C: AsRef<SetChatPhoto>>(&self, set_chat_photo: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_photo.as_ref()).await
   }
 
+  pub async fn set_chat_slow_mode_delay<C: AsRef<SetChatSlowModeDelay>>(&self, set_chat_slow_mode_delay: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_chat_slow_mode_delay.as_ref()).await
+  }
+
   pub async fn set_chat_title<C: AsRef<SetChatTitle>>(&self, set_chat_title: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_title.as_ref()).await
@@ -1521,11 +1671,6 @@ impl AsyncApi {
     async_caller(&self.api, set_sticker_position_in_set.as_ref()).await
   }
 
-  pub async fn set_supergroup_description<C: AsRef<SetSupergroupDescription>>(&self, set_supergroup_description: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
-    async_caller(&self.api, set_supergroup_description.as_ref()).await
-  }
-
   pub async fn set_supergroup_sticker_set<C: AsRef<SetSupergroupStickerSet>>(&self, set_supergroup_sticker_set: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_supergroup_sticker_set.as_ref()).await
@@ -1551,6 +1696,11 @@ impl AsyncApi {
     async_caller(&self.api, set_username.as_ref()).await
   }
 
+  pub async fn share_phone_number<C: AsRef<SharePhoneNumber>>(&self, share_phone_number: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, share_phone_number.as_ref()).await
+  }
+
   pub async fn stop_poll<C: AsRef<StopPoll>>(&self, stop_poll: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, stop_poll.as_ref()).await
@@ -1616,26 +1766,26 @@ impl AsyncApi {
     async_caller(&self.api, test_network.as_ref()).await
   }
 
+  pub async fn test_proxy<C: AsRef<TestProxy>>(&self, test_proxy: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, test_proxy.as_ref()).await
+  }
+
+  pub async fn test_return_error<C: AsRef<TestReturnError>>(&self, test_return_error: C) -> RTDResult<Error> {
+    async_caller!(Error);
+    async_caller(&self.api, test_return_error.as_ref()).await
+  }
+
   pub async fn test_square_int<C: AsRef<TestSquareInt>>(&self, test_square_int: C) -> RTDResult<TestInt> {
     async_caller!(TestInt);
     async_caller(&self.api, test_square_int.as_ref()).await
   }
 
-  pub async fn test_use_error<C: AsRef<TestUseError>>(&self, test_use_error: C) -> RTDResult<Error> {
-    async_caller!(Error);
-    async_caller(&self.api, test_use_error.as_ref()).await
-  }
-
   pub async fn test_use_update<C: AsRef<TestUseUpdate>>(&self, test_use_update: C) -> RTDResult<Update> {
     async_caller!(Update);
     async_caller(&self.api, test_use_update.as_ref()).await
   }
 
-  pub async fn toggle_basic_group_administrators<C: AsRef<ToggleBasicGroupAdministrators>>(&self, toggle_basic_group_administrators: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
-    async_caller(&self.api, toggle_basic_group_administrators.as_ref()).await
-  }
-
   pub async fn toggle_chat_default_disable_notification<C: AsRef<ToggleChatDefaultDisableNotification>>(&self, toggle_chat_default_disable_notification: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, toggle_chat_default_disable_notification.as_ref()).await
@@ -1651,11 +1801,6 @@ impl AsyncApi {
     async_caller(&self.api, toggle_chat_is_pinned.as_ref()).await
   }
 
-  pub async fn toggle_supergroup_invites<C: AsRef<ToggleSupergroupInvites>>(&self, toggle_supergroup_invites: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
-    async_caller(&self.api, toggle_supergroup_invites.as_ref()).await
-  }
-
   pub async fn toggle_supergroup_is_all_history_available<C: AsRef<ToggleSupergroupIsAllHistoryAvailable>>(&self, toggle_supergroup_is_all_history_available: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, toggle_supergroup_is_all_history_available.as_ref()).await
@@ -1666,6 +1811,11 @@ impl AsyncApi {
     async_caller(&self.api, toggle_supergroup_sign_messages.as_ref()).await
   }
 
+  pub async fn transfer_chat_ownership<C: AsRef<TransferChatOwnership>>(&self, transfer_chat_ownership: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, transfer_chat_ownership.as_ref()).await
+  }
+
   pub async fn unblock_user<C: AsRef<UnblockUser>>(&self, unblock_user: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, unblock_user.as_ref()).await
