@@ -37,6 +37,10 @@ impl EventApi {
     self.api.send(add_chat_members.as_ref())
   }
 
+  pub fn add_contact<C: AsRef<AddContact>>(&self, add_contact: C) -> RTDResult<()> {
+    self.api.send(add_contact.as_ref())
+  }
+
   pub fn add_custom_server_language_pack<C: AsRef<AddCustomServerLanguagePack>>(&self, add_custom_server_language_pack: C) -> RTDResult<()> {
     self.api.send(add_custom_server_language_pack.as_ref())
   }
@@ -101,6 +105,10 @@ impl EventApi {
     self.api.send(block_user.as_ref())
   }
 
+  pub fn can_transfer_ownership<C: AsRef<CanTransferOwnership>>(&self, can_transfer_ownership: C) -> RTDResult<()> {
+    self.api.send(can_transfer_ownership.as_ref())
+  }
+
   pub fn cancel_download_file<C: AsRef<CancelDownloadFile>>(&self, cancel_download_file: C) -> RTDResult<()> {
     self.api.send(cancel_download_file.as_ref())
   }
@@ -109,10 +117,6 @@ impl EventApi {
     self.api.send(cancel_upload_file.as_ref())
   }
 
-  pub fn change_chat_report_spam_state<C: AsRef<ChangeChatReportSpamState>>(&self, change_chat_report_spam_state: C) -> RTDResult<()> {
-    self.api.send(change_chat_report_spam_state.as_ref())
-  }
-
   pub fn change_imported_contacts<C: AsRef<ChangeImportedContacts>>(&self, change_imported_contacts: C) -> RTDResult<()> {
     self.api.send(change_imported_contacts.as_ref())
   }
@@ -149,6 +153,10 @@ impl EventApi {
     self.api.send(check_chat_username.as_ref())
   }
 
+  pub fn check_created_public_chats_limit<C: AsRef<CheckCreatedPublicChatsLimit>>(&self, check_created_public_chats_limit: C) -> RTDResult<()> {
+    self.api.send(check_created_public_chats_limit.as_ref())
+  }
+
   pub fn check_database_encryption_key<C: AsRef<CheckDatabaseEncryptionKey>>(&self, check_database_encryption_key: C) -> RTDResult<()> {
     self.api.send(check_database_encryption_key.as_ref())
   }
@@ -201,6 +209,10 @@ impl EventApi {
     self.api.send(close_secret_chat.as_ref())
   }
 
+  pub fn confirm_qr_code_authentication<C: AsRef<ConfirmQrCodeAuthentication>>(&self, confirm_qr_code_authentication: C) -> RTDResult<()> {
+    self.api.send(confirm_qr_code_authentication.as_ref())
+  }
+
   pub fn create_basic_group_chat<C: AsRef<CreateBasicGroupChat>>(&self, create_basic_group_chat: C) -> RTDResult<()> {
     self.api.send(create_basic_group_chat.as_ref())
   }
@@ -353,6 +365,10 @@ impl EventApi {
     self.api.send(edit_message_reply_markup.as_ref())
   }
 
+  pub fn edit_message_scheduling_state<C: AsRef<EditMessageSchedulingState>>(&self, edit_message_scheduling_state: C) -> RTDResult<()> {
+    self.api.send(edit_message_scheduling_state.as_ref())
+  }
+
   pub fn edit_message_text<C: AsRef<EditMessageText>>(&self, edit_message_text: C) -> RTDResult<()> {
     self.api.send(edit_message_text.as_ref())
   }
@@ -409,6 +425,18 @@ impl EventApi {
     self.api.send(get_authorization_state.as_ref())
   }
 
+  pub fn get_auto_download_settings_presets<C: AsRef<GetAutoDownloadSettingsPresets>>(&self, get_auto_download_settings_presets: C) -> RTDResult<()> {
+    self.api.send(get_auto_download_settings_presets.as_ref())
+  }
+
+  pub fn get_background_url<C: AsRef<GetBackgroundUrl>>(&self, get_background_url: C) -> RTDResult<()> {
+    self.api.send(get_background_url.as_ref())
+  }
+
+  pub fn get_backgrounds<C: AsRef<GetBackgrounds>>(&self, get_backgrounds: C) -> RTDResult<()> {
+    self.api.send(get_backgrounds.as_ref())
+  }
+
   pub fn get_basic_group<C: AsRef<GetBasicGroup>>(&self, get_basic_group: C) -> RTDResult<()> {
     self.api.send(get_basic_group.as_ref())
   }
@@ -461,8 +489,8 @@ impl EventApi {
     self.api.send(get_chat_pinned_message.as_ref())
   }
 
-  pub fn get_chat_report_spam_state<C: AsRef<GetChatReportSpamState>>(&self, get_chat_report_spam_state: C) -> RTDResult<()> {
-    self.api.send(get_chat_report_spam_state.as_ref())
+  pub fn get_chat_scheduled_messages<C: AsRef<GetChatScheduledMessages>>(&self, get_chat_scheduled_messages: C) -> RTDResult<()> {
+    self.api.send(get_chat_scheduled_messages.as_ref())
   }
 
   pub fn get_chat_statistics_url<C: AsRef<GetChatStatisticsUrl>>(&self, get_chat_statistics_url: C) -> RTDResult<()> {
@@ -501,6 +529,10 @@ impl EventApi {
     self.api.send(get_deep_link_info.as_ref())
   }
 
+  pub fn get_emoji_suggestions_url<C: AsRef<GetEmojiSuggestionsUrl>>(&self, get_emoji_suggestions_url: C) -> RTDResult<()> {
+    self.api.send(get_emoji_suggestions_url.as_ref())
+  }
+
   pub fn get_favorite_stickers<C: AsRef<GetFavoriteStickers>>(&self, get_favorite_stickers: C) -> RTDResult<()> {
     self.api.send(get_favorite_stickers.as_ref())
   }
@@ -533,6 +565,10 @@ impl EventApi {
     self.api.send(get_imported_contact_count.as_ref())
   }
 
+  pub fn get_inactive_supergroup_chats<C: AsRef<GetInactiveSupergroupChats>>(&self, get_inactive_supergroup_chats: C) -> RTDResult<()> {
+    self.api.send(get_inactive_supergroup_chats.as_ref())
+  }
+
   pub fn get_inline_game_high_scores<C: AsRef<GetInlineGameHighScores>>(&self, get_inline_game_high_scores: C) -> RTDResult<()> {
     self.api.send(get_inline_game_high_scores.as_ref())
   }
@@ -589,6 +625,14 @@ impl EventApi {
     self.api.send(get_log_verbosity_level.as_ref())
   }
 
+  pub fn get_login_url<C: AsRef<GetLoginUrl>>(&self, get_login_url: C) -> RTDResult<()> {
+    self.api.send(get_login_url.as_ref())
+  }
+
+  pub fn get_login_url_info<C: AsRef<GetLoginUrlInfo>>(&self, get_login_url_info: C) -> RTDResult<()> {
+    self.api.send(get_login_url_info.as_ref())
+  }
+
   pub fn get_map_thumbnail_file<C: AsRef<GetMapThumbnailFile>>(&self, get_map_thumbnail_file: C) -> RTDResult<()> {
     self.api.send(get_map_thumbnail_file.as_ref())
   }
@@ -605,6 +649,10 @@ impl EventApi {
     self.api.send(get_message_link.as_ref())
   }
 
+  pub fn get_message_link_info<C: AsRef<GetMessageLinkInfo>>(&self, get_message_link_info: C) -> RTDResult<()> {
+    self.api.send(get_message_link_info.as_ref())
+  }
+
   pub fn get_message_locally<C: AsRef<GetMessageLocally>>(&self, get_message_locally: C) -> RTDResult<()> {
     self.api.send(get_message_locally.as_ref())
   }
@@ -645,6 +693,10 @@ impl EventApi {
     self.api.send(get_payment_receipt.as_ref())
   }
 
+  pub fn get_poll_voters<C: AsRef<GetPollVoters>>(&self, get_poll_voters: C) -> RTDResult<()> {
+    self.api.send(get_poll_voters.as_ref())
+  }
+
   pub fn get_preferred_country_language<C: AsRef<GetPreferredCountryLanguage>>(&self, get_preferred_country_language: C) -> RTDResult<()> {
     self.api.send(get_preferred_country_language.as_ref())
   }
@@ -725,6 +777,10 @@ impl EventApi {
     self.api.send(get_storage_statistics_fast.as_ref())
   }
 
+  pub fn get_suitable_discussion_chats<C: AsRef<GetSuitableDiscussionChats>>(&self, get_suitable_discussion_chats: C) -> RTDResult<()> {
+    self.api.send(get_suitable_discussion_chats.as_ref())
+  }
+
   pub fn get_supergroup<C: AsRef<GetSupergroup>>(&self, get_supergroup: C) -> RTDResult<()> {
     self.api.send(get_supergroup.as_ref())
   }
@@ -773,10 +829,6 @@ impl EventApi {
     self.api.send(get_user_profile_photos.as_ref())
   }
 
-  pub fn get_wallpapers<C: AsRef<GetWallpapers>>(&self, get_wallpapers: C) -> RTDResult<()> {
-    self.api.send(get_wallpapers.as_ref())
-  }
-
   pub fn get_web_page_instant_view<C: AsRef<GetWebPageInstantView>>(&self, get_web_page_instant_view: C) -> RTDResult<()> {
     self.api.send(get_web_page_instant_view.as_ref())
   }
@@ -853,6 +905,18 @@ impl EventApi {
     self.api.send(register_device.as_ref())
   }
 
+  pub fn register_user<C: AsRef<RegisterUser>>(&self, register_user: C) -> RTDResult<()> {
+    self.api.send(register_user.as_ref())
+  }
+
+  pub fn remove_background<C: AsRef<RemoveBackground>>(&self, remove_background: C) -> RTDResult<()> {
+    self.api.send(remove_background.as_ref())
+  }
+
+  pub fn remove_chat_action_bar<C: AsRef<RemoveChatActionBar>>(&self, remove_chat_action_bar: C) -> RTDResult<()> {
+    self.api.send(remove_chat_action_bar.as_ref())
+  }
+
   pub fn remove_contacts<C: AsRef<RemoveContacts>>(&self, remove_contacts: C) -> RTDResult<()> {
     self.api.send(remove_contacts.as_ref())
   }
@@ -917,6 +981,10 @@ impl EventApi {
     self.api.send(request_password_recovery.as_ref())
   }
 
+  pub fn request_qr_code_authentication<C: AsRef<RequestQrCodeAuthentication>>(&self, request_qr_code_authentication: C) -> RTDResult<()> {
+    self.api.send(request_qr_code_authentication.as_ref())
+  }
+
   pub fn resend_authentication_code<C: AsRef<ResendAuthenticationCode>>(&self, resend_authentication_code: C) -> RTDResult<()> {
     self.api.send(resend_authentication_code.as_ref())
   }
@@ -929,6 +997,10 @@ impl EventApi {
     self.api.send(resend_email_address_verification_code.as_ref())
   }
 
+  pub fn resend_messages<C: AsRef<ResendMessages>>(&self, resend_messages: C) -> RTDResult<()> {
+    self.api.send(resend_messages.as_ref())
+  }
+
   pub fn resend_phone_number_confirmation_code<C: AsRef<ResendPhoneNumberConfirmationCode>>(&self, resend_phone_number_confirmation_code: C) -> RTDResult<()> {
     self.api.send(resend_phone_number_confirmation_code.as_ref())
   }
@@ -945,6 +1017,10 @@ impl EventApi {
     self.api.send(reset_all_notification_settings.as_ref())
   }
 
+  pub fn reset_backgrounds<C: AsRef<ResetBackgrounds>>(&self, reset_backgrounds: C) -> RTDResult<()> {
+    self.api.send(reset_backgrounds.as_ref())
+  }
+
   pub fn reset_network_statistics<C: AsRef<ResetNetworkStatistics>>(&self, reset_network_statistics: C) -> RTDResult<()> {
     self.api.send(reset_network_statistics.as_ref())
   }
@@ -953,6 +1029,10 @@ impl EventApi {
     self.api.send(save_application_log_event.as_ref())
   }
 
+  pub fn search_background<C: AsRef<SearchBackground>>(&self, search_background: C) -> RTDResult<()> {
+    self.api.send(search_background.as_ref())
+  }
+
   pub fn search_call_messages<C: AsRef<SearchCallMessages>>(&self, search_call_messages: C) -> RTDResult<()> {
     self.api.send(search_call_messages.as_ref())
   }
@@ -973,6 +1053,10 @@ impl EventApi {
     self.api.send(search_chats.as_ref())
   }
 
+  pub fn search_chats_nearby<C: AsRef<SearchChatsNearby>>(&self, search_chats_nearby: C) -> RTDResult<()> {
+    self.api.send(search_chats_nearby.as_ref())
+  }
+
   pub fn search_chats_on_server<C: AsRef<SearchChatsOnServer>>(&self, search_chats_on_server: C) -> RTDResult<()> {
     self.api.send(search_chats_on_server.as_ref())
   }
@@ -981,6 +1065,10 @@ impl EventApi {
     self.api.send(search_contacts.as_ref())
   }
 
+  pub fn search_emojis<C: AsRef<SearchEmojis>>(&self, search_emojis: C) -> RTDResult<()> {
+    self.api.send(search_emojis.as_ref())
+  }
+
   pub fn search_hashtags<C: AsRef<SearchHashtags>>(&self, search_hashtags: C) -> RTDResult<()> {
     self.api.send(search_hashtags.as_ref())
   }
@@ -1089,6 +1177,14 @@ impl EventApi {
     self.api.send(set_authentication_phone_number.as_ref())
   }
 
+  pub fn set_auto_download_settings<C: AsRef<SetAutoDownloadSettings>>(&self, set_auto_download_settings: C) -> RTDResult<()> {
+    self.api.send(set_auto_download_settings.as_ref())
+  }
+
+  pub fn set_background<C: AsRef<SetBackground>>(&self, set_background: C) -> RTDResult<()> {
+    self.api.send(set_background.as_ref())
+  }
+
   pub fn set_bio<C: AsRef<SetBio>>(&self, set_bio: C) -> RTDResult<()> {
     self.api.send(set_bio.as_ref())
   }
@@ -1097,14 +1193,30 @@ impl EventApi {
     self.api.send(set_bot_updates_status.as_ref())
   }
 
+  pub fn set_chat_chat_list<C: AsRef<SetChatChatList>>(&self, set_chat_chat_list: C) -> RTDResult<()> {
+    self.api.send(set_chat_chat_list.as_ref())
+  }
+
   pub fn set_chat_client_data<C: AsRef<SetChatClientData>>(&self, set_chat_client_data: C) -> RTDResult<()> {
     self.api.send(set_chat_client_data.as_ref())
   }
 
+  pub fn set_chat_description<C: AsRef<SetChatDescription>>(&self, set_chat_description: C) -> RTDResult<()> {
+    self.api.send(set_chat_description.as_ref())
+  }
+
+  pub fn set_chat_discussion_group<C: AsRef<SetChatDiscussionGroup>>(&self, set_chat_discussion_group: C) -> RTDResult<()> {
+    self.api.send(set_chat_discussion_group.as_ref())
+  }
+
   pub fn set_chat_draft_message<C: AsRef<SetChatDraftMessage>>(&self, set_chat_draft_message: C) -> RTDResult<()> {
     self.api.send(set_chat_draft_message.as_ref())
   }
 
+  pub fn set_chat_location<C: AsRef<SetChatLocation>>(&self, set_chat_location: C) -> RTDResult<()> {
+    self.api.send(set_chat_location.as_ref())
+  }
+
   pub fn set_chat_member_status<C: AsRef<SetChatMemberStatus>>(&self, set_chat_member_status: C) -> RTDResult<()> {
     self.api.send(set_chat_member_status.as_ref())
   }
@@ -1113,10 +1225,18 @@ impl EventApi {
     self.api.send(set_chat_notification_settings.as_ref())
   }
 
+  pub fn set_chat_permissions<C: AsRef<SetChatPermissions>>(&self, set_chat_permissions: C) -> RTDResult<()> {
+    self.api.send(set_chat_permissions.as_ref())
+  }
+
   pub fn set_chat_photo<C: AsRef<SetChatPhoto>>(&self, set_chat_photo: C) -> RTDResult<()> {
     self.api.send(set_chat_photo.as_ref())
   }
 
+  pub fn set_chat_slow_mode_delay<C: AsRef<SetChatSlowModeDelay>>(&self, set_chat_slow_mode_delay: C) -> RTDResult<()> {
+    self.api.send(set_chat_slow_mode_delay.as_ref())
+  }
+
   pub fn set_chat_title<C: AsRef<SetChatTitle>>(&self, set_chat_title: C) -> RTDResult<()> {
     self.api.send(set_chat_title.as_ref())
   }
@@ -1205,10 +1325,6 @@ impl EventApi {
     self.api.send(set_sticker_position_in_set.as_ref())
   }
 
-  pub fn set_supergroup_description<C: AsRef<SetSupergroupDescription>>(&self, set_supergroup_description: C) -> RTDResult<()> {
-    self.api.send(set_supergroup_description.as_ref())
-  }
-
   pub fn set_supergroup_sticker_set<C: AsRef<SetSupergroupStickerSet>>(&self, set_supergroup_sticker_set: C) -> RTDResult<()> {
     self.api.send(set_supergroup_sticker_set.as_ref())
   }
@@ -1229,6 +1345,10 @@ impl EventApi {
     self.api.send(set_username.as_ref())
   }
 
+  pub fn share_phone_number<C: AsRef<SharePhoneNumber>>(&self, share_phone_number: C) -> RTDResult<()> {
+    self.api.send(share_phone_number.as_ref())
+  }
+
   pub fn stop_poll<C: AsRef<StopPoll>>(&self, stop_poll: C) -> RTDResult<()> {
     self.api.send(stop_poll.as_ref())
   }
@@ -1281,22 +1401,22 @@ impl EventApi {
     self.api.send(test_network.as_ref())
   }
 
+  pub fn test_proxy<C: AsRef<TestProxy>>(&self, test_proxy: C) -> RTDResult<()> {
+    self.api.send(test_proxy.as_ref())
+  }
+
+  pub fn test_return_error<C: AsRef<TestReturnError>>(&self, test_return_error: C) -> RTDResult<()> {
+    self.api.send(test_return_error.as_ref())
+  }
+
   pub fn test_square_int<C: AsRef<TestSquareInt>>(&self, test_square_int: C) -> RTDResult<()> {
     self.api.send(test_square_int.as_ref())
   }
 
-  pub fn test_use_error<C: AsRef<TestUseError>>(&self, test_use_error: C) -> RTDResult<()> {
-    self.api.send(test_use_error.as_ref())
-  }
-
   pub fn test_use_update<C: AsRef<TestUseUpdate>>(&self, test_use_update: C) -> RTDResult<()> {
     self.api.send(test_use_update.as_ref())
   }
 
-  pub fn toggle_basic_group_administrators<C: AsRef<ToggleBasicGroupAdministrators>>(&self, toggle_basic_group_administrators: C) -> RTDResult<()> {
-    self.api.send(toggle_basic_group_administrators.as_ref())
-  }
-
   pub fn toggle_chat_default_disable_notification<C: AsRef<ToggleChatDefaultDisableNotification>>(&self, toggle_chat_default_disable_notification: C) -> RTDResult<()> {
     self.api.send(toggle_chat_default_disable_notification.as_ref())
   }
@@ -1309,10 +1429,6 @@ impl EventApi {
     self.api.send(toggle_chat_is_pinned.as_ref())
   }
 
-  pub fn toggle_supergroup_invites<C: AsRef<ToggleSupergroupInvites>>(&self, toggle_supergroup_invites: C) -> RTDResult<()> {
-    self.api.send(toggle_supergroup_invites.as_ref())
-  }
-
   pub fn toggle_supergroup_is_all_history_available<C: AsRef<ToggleSupergroupIsAllHistoryAvailable>>(&self, toggle_supergroup_is_all_history_available: C) -> RTDResult<()> {
     self.api.send(toggle_supergroup_is_all_history_available.as_ref())
   }
@@ -1321,6 +1437,10 @@ impl EventApi {
     self.api.send(toggle_supergroup_sign_messages.as_ref())
   }
 
+  pub fn transfer_chat_ownership<C: AsRef<TransferChatOwnership>>(&self, transfer_chat_ownership: C) -> RTDResult<()> {
+    self.api.send(transfer_chat_ownership.as_ref())
+  }
+
   pub fn unblock_user<C: AsRef<UnblockUser>>(&self, unblock_user: C) -> RTDResult<()> {
     self.api.send(unblock_user.as_ref())
   }
