@@ -36,10 +36,16 @@ impl Observer {
 
       TdType::UpdateCall(value) => value.extra(),
 
+      TdType::UpdateChatActionBar(value) => value.extra(),
+
+      TdType::UpdateChatChatList(value) => value.extra(),
+
       TdType::UpdateChatDefaultDisableNotification(value) => value.extra(),
 
       TdType::UpdateChatDraftMessage(value) => value.extra(),
 
+      TdType::UpdateChatHasScheduledMessages(value) => value.extra(),
+
       TdType::UpdateChatIsMarkedAsUnread(value) => value.extra(),
 
       TdType::UpdateChatIsPinned(value) => value.extra(),
@@ -54,6 +60,8 @@ impl Observer {
 
       TdType::UpdateChatOrder(value) => value.extra(),
 
+      TdType::UpdateChatPermissions(value) => value.extra(),
+
       TdType::UpdateChatPhoto(value) => value.extra(),
 
       TdType::UpdateChatPinnedMessage(value) => value.extra(),
@@ -92,6 +100,8 @@ impl Observer {
 
       TdType::UpdateMessageEdited(value) => value.extra(),
 
+      TdType::UpdateMessageLiveLocationViewed(value) => value.extra(),
+
       TdType::UpdateMessageMentionRead(value) => value.extra(),
 
       TdType::UpdateMessageSendAcknowledged(value) => value.extra(),
@@ -130,6 +140,8 @@ impl Observer {
 
       TdType::UpdatePoll(value) => value.extra(),
 
+      TdType::UpdatePollAnswer(value) => value.extra(),
+
       TdType::UpdateRecentStickers(value) => value.extra(),
 
       TdType::UpdateSavedAnimations(value) => value.extra(),
@@ -138,6 +150,8 @@ impl Observer {
 
       TdType::UpdateSecretChat(value) => value.extra(),
 
+      TdType::UpdateSelectedBackground(value) => value.extra(),
+
       TdType::UpdateServiceNotification(value) => value.extra(),
 
       TdType::UpdateSupergroup(value) => value.extra(),
@@ -162,9 +176,13 @@ impl Observer {
 
       TdType::UpdateUserStatus(value) => value.extra(),
 
+      TdType::UpdateUsersNearby(value) => value.extra(),
+
 
       TdType::AuthorizationState(value) => value.extra(),
 
+      TdType::CanTransferOwnershipResult(value) => value.extra(),
+
       TdType::CheckChatUsernameResult(value) => value.extra(),
 
       TdType::JsonValue(value) => value.extra(),
@@ -173,6 +191,8 @@ impl Observer {
 
       TdType::LogStream(value) => value.extra(),
 
+      TdType::LoginUrlInfo(value) => value.extra(),
+
       TdType::OptionValue(value) => value.extra(),
 
       TdType::PassportElement(value) => value.extra(),
@@ -185,6 +205,12 @@ impl Observer {
 
       TdType::AuthenticationCodeInfo(value) => value.extra(),
 
+      TdType::AutoDownloadSettingsPresets(value) => value.extra(),
+
+      TdType::Background(value) => value.extra(),
+
+      TdType::Backgrounds(value) => value.extra(),
+
       TdType::BasicGroup(value) => value.extra(),
 
       TdType::BasicGroupFullInfo(value) => value.extra(),
@@ -195,6 +221,8 @@ impl Observer {
 
       TdType::Chat(value) => value.extra(),
 
+      TdType::ChatAdministrators(value) => value.extra(),
+
       TdType::ChatEvents(value) => value.extra(),
 
       TdType::ChatInviteLink(value) => value.extra(),
@@ -205,10 +233,10 @@ impl Observer {
 
       TdType::ChatMembers(value) => value.extra(),
 
-      TdType::ChatReportSpamState(value) => value.extra(),
-
       TdType::Chats(value) => value.extra(),
 
+      TdType::ChatsNearby(value) => value.extra(),
+
       TdType::ConnectedWebsites(value) => value.extra(),
 
       TdType::Count(value) => value.extra(),
@@ -221,6 +249,8 @@ impl Observer {
 
       TdType::EmailAddressAuthenticationCodeInfo(value) => value.extra(),
 
+      TdType::Emojis(value) => value.extra(),
+
       TdType::Error(value) => value.extra(),
 
       TdType::File(value) => value.extra(),
@@ -253,6 +283,8 @@ impl Observer {
 
       TdType::Message(value) => value.extra(),
 
+      TdType::MessageLinkInfo(value) => value.extra(),
+
       TdType::Messages(value) => value.extra(),
 
       TdType::NetworkStatistics(value) => value.extra(),
@@ -291,9 +323,9 @@ impl Observer {
 
       TdType::SecretChat(value) => value.extra(),
 
-      TdType::Sessions(value) => value.extra(),
+      TdType::Session(value) => value.extra(),
 
-      TdType::StickerEmojis(value) => value.extra(),
+      TdType::Sessions(value) => value.extra(),
 
       TdType::StickerSet(value) => value.extra(),
 
@@ -345,8 +377,6 @@ impl Observer {
 
       TdType::ValidatedOrderInfo(value) => value.extra(),
 
-      TdType::Wallpapers(value) => value.extra(),
-
       TdType::WebPage(value) => value.extra(),
 
       TdType::WebPageInstantView(value) => value.extra(),
